@@ -1,10 +1,18 @@
 #-*- coding: utf-8 -*-
+import sys
 import phonenumbers
 from django.core import validators
 from phonenumbers.phonenumberutil import NumberParseException
 from django.conf import settings
 
 
+# Snippet from the `six` library to help with Python3 compatibility
+if sys.version_info[0] == 3:
+    string_types = str
+else:
+    string_types = basestring
+
+
 class PhoneNumber(phonenumbers.phonenumber.PhoneNumber):
     """
     A extended version of phonenumbers.phonenumber.PhoneNumber that provides some neat and more pythonic, easy
@@ -74,10 +82,10 @@ class PhoneNumber(phonenumbers.phonenumber.PhoneNumber):
 def to_python(value):
     if value in validators.EMPTY_VALUES:  # None or ''
         phone_number = None
-    elif value and isinstance(value, basestring):
+    elif value and isinstance(value, string_types):
         try:
             phone_number = PhoneNumber.from_string(phone_number=value)
-        except NumberParseException, e:
+        except NumberParseException:
             # the string provided is not a valid PhoneNumber.
             phone_number = PhoneNumber(raw_input=value)
     elif isinstance(value, phonenumbers.phonenumber.PhoneNumber) and \
